@@ -653,7 +653,7 @@ class Marker(_MapFeature):
 
     @classmethod
     def map_table(cls, table, clustered_marker=False, include_color_scale_outliers=True, radius_in_meters=False, **kwargs):
-        """Return markers from the colums of a table.
+        """Return markers from the columns of a table.
         
         The first two columns of the table must be the latitudes and longitudes
         (in that order), followed by 'labels', 'colors', 'color_scale', 'radius_scale', 'cluster_by', 'area_scale', and/or 'areas' (if applicable)
@@ -770,7 +770,7 @@ class Circle(Marker):
 
     For example, to draw three circles with circle_marker:
 
-    ..code-block:: python
+    .. code-block:: python
 
         t = Table().with_columns([
                 'lat', [37.8, 38, 37.9],
@@ -783,7 +783,7 @@ class Circle(Marker):
 
     To draw three circles with the circle methods, replace the last line with:
 
-    ..code-block:: python
+    .. code-block:: python
     
         Circle.map_table(t, radius_in_meters=True)
     """
